@@ -3,8 +3,8 @@ import logging
 
 from roborock.containers import HomeDataDevice, HomeDataDeviceField, HomeDataProduct, HomeDataProductField, NetworkInfo, \
     NetworkInfoField
+from roborock.containers import RoborockLocalDeviceInfo
 from roborock.local_api import RoborockLocalClient
-from roborock.typing import RoborockLocalDeviceInfo
 
 local_ip = "<local_ip>"
 local_key = "<local_key>"
@@ -16,17 +16,21 @@ async def main():
         "level": logging.DEBUG
     }
     logging.basicConfig(**logging_config)
-    client = RoborockLocalClient({
-        device_id: RoborockLocalDeviceInfo(HomeDataDevice({
+    localdevices_info = RoborockLocalDeviceInfo({
+        "device": HomeDataDevice({
             HomeDataDeviceField.NAME: "test_name",
             HomeDataDeviceField.DUID: device_id,
             HomeDataDeviceField.FV: "1",
             HomeDataDeviceField.LOCAL_KEY: local_key
-        }), HomeDataProduct({
+        }),
+        "product": HomeDataProduct({
             HomeDataProductField.MODEL: "test_model"
-        }), NetworkInfo({
+        }),
+        "network_info": NetworkInfo({
             NetworkInfoField.IP: local_ip
-        }))
+        })})
+    client = RoborockLocalClient({
+        device_id: localdevices_info
     })
     await client.async_connect()
     props = await client.get_prop(device_id)
